@@ -55,10 +55,13 @@ public:
     void Test5554(void);
     void Test9237(void);
     void TestParsing(void);
+    void Test12902_yWithGregoCalInThaiLoc(void);
     void TestT10334(void);
     void TestT10619(void);
     void TestT10855(void);
+    void TestT10858(void);
     void TestT10906(void);
+    void TestT13380(void);
  };
 
 #endif /* #if !UCONFIG_NO_FORMATTING */
